{% extends "base.html" %}

{% block content %}

<div class="flex flex-wrap -mx-3 mb-6">
  <div class="w-full px-3">
    <h2 class="text-2xl font-semibold leading-7 text-gray-900 sm:text-3xl sm:leading-9">{{_('Index')}}</h2>
    {{_('Ight this is the index, the landing page where we have all the features and stuffs.')}}
  </div>

  {% endblock %}